@@ -22,6 +22,6 @@
   (if (= (length args) 0)
       (system "dict --help")
       (begin
-	(fh-set-current-target-buddy! "dict")  
+	(fh-set-current-target-buddy! "dict" "send")  
 	(system (string-append "dict -P more \"" (list->asv args " ") "\"")))))
 
