@@ -19,14 +19,16 @@
 (use-modules (ice-9 rdelim))
 
 
-(display "Loading words from sorted dictionary [/usr/share/dict/words]... ")
-(catch 'system-error
-       (lambda ()
-	 (for-each-line (lambda (word)
-			  (fh-dict-add-word-sorted! word))
-			"/usr/share/dict/words"))
-       (lambda args #f))
-(display "done.\n")
+(display "Loading dictionary [/usr/share/dict/words]... ")
+(let ((word-count 0))
+  (catch 'system-error
+	 (lambda ()
+	   (for-each-line (lambda (word)
+			    (fh-dict-add-word-sorted! word)
+			    (set! word-count (1+ word-count)))
+			  "/usr/share/dict/words"))
+	 (lambda args #f))
+  (display (string-append "[" (number->string word-count) "] words\n")))
 
 ;; Add sent-words to readline context"
 (add-hook! fh-message-send-hook 
