@@ -1078,6 +1078,7 @@ command_buddy_add (char *line)
 {
   char *user_id = NULL;
   char *group = NULL;
+  char *msg = NULL;
   
   user_id = get_token (&line);
   if (user_id == (char *) NULL)
@@ -1087,9 +1088,8 @@ command_buddy_add (char *line)
     }
   
   group = get_token (&line);
-  
+  msg = line;
   /*
-    FIXME: Visu, Aug 23, 2004:
     ==========================
     1. The following function prototype is changed from previous
     libyahoo2 versions.
@@ -1098,7 +1098,8 @@ command_buddy_add (char *line)
     needs a revisit and approprite string to be passed if required.
   */
   yahoo_add_buddy (get_fh_session ()->id, user_id, 
-		   ((group == NULL) ? FH_DEFAULT_GROUP : group), "");
+		   ((group == NULL) ? FH_DEFAULT_GROUP : group), 
+		   ((msg == NULL) ? "" : msg));
 }
 
 void
@@ -1146,7 +1147,7 @@ command_buddy_reject (char *line)
       return;
     }
   
-  mesg = get_token (&line);
+  mesg = line;
   if (!mesg)
     mesg = "";
   yahoo_reject_buddy (get_fh_session ()->id, user_id, mesg);
