@@ -41,7 +41,7 @@ void toggle_session (void);
 void toggle_status (void);
 
 int get_current_status (void);
-void set_current_status (int current_status_value);
+void set_current_status (long current_status_value);
 
 char *get_current_status_custom_message (void);
 void set_current_status_custom_message (char *current_status_custom_message_value);
