@@ -300,13 +300,13 @@ ex_get_buddy_list ()
 
 
 SCM
-ex_add_buddy (SCM scm_buddy, SCM scm_group)
+ex_add_buddy (SCM scm_buddy, SCM scm_group, SCM scm_msg)
 {
   char *buddy =  (scm_to_locale_string (scm_buddy));
   char *group =  (scm_to_locale_string (scm_group));
+  char *msg = (scm_to_locale_string (scm_msg));
   
   /*
-    FIXME: Visu, Aug 23, 2004:
     ==========================
     1. The following function prototype is changed from previous
        libyahoo2 versions.
@@ -315,8 +315,9 @@ ex_add_buddy (SCM scm_buddy, SCM scm_group)
        needs a revisit and approprite string to be passed if required.
   */
   yahoo_add_buddy (get_fh_session ()->id, buddy, 
-		   ((group == NULL) ? FH_DEFAULT_GROUP : group), "");
-  free(buddy); free(group);
+		   ((group == NULL) ? FH_DEFAULT_GROUP : group),
+		   ((msg == NULL) ? "" : msg));
+  free(buddy); free(group); free(msg);
   return SCM_UNSPECIFIED;
 }
 
