@@ -40,7 +40,7 @@ SCM ex_register_command_x (SCM command);
 SCM ex_unregister_command_x (SCM command);
 SCM ex_set_prompt_x (SCM scm_prompt);
 SCM ex_get_buddy_list ();
-SCM ex_add_buddy (SCM scm_buddy, SCM scm_group);
+SCM ex_add_buddy (SCM scm_buddy, SCM scm_group, SCM scm_msg);
 SCM ex_fh_quit ();
 SCM ex_fh_logoff ();
 SCM ex_fh_dict_add_word (SCM word);
