@@ -20,7 +20,7 @@
 #define _YAHOO_ADAPTER_H
 
 #include <glib.h>
-#include <yahoo2.h>
+#include <libyahoo2/yahoo2.h>
 
 // yahoo status
 #define YAHOO_STATUS_UNKNOWN -1
@@ -32,7 +32,7 @@ void set_auto_insert_mode (int auto_insert_mode_value);
 
 char *get_received_message_from (void);
 
-void set_current_target_buddy (char *current_target_buddy_value, current_target_buddy_mode_t mode);
+void set_current_target_buddy (const char *current_target_buddy_value, current_target_buddy_mode_t mode);
 char *get_current_target_buddy (current_target_buddy_mode_t *mode);
 
 void send_message (char *to, char *message);
