@@ -67,7 +67,7 @@
 #include "extension.h"
 #include "compat.h"
 
-// static char *local_host = "127.0.0.1";
+static char *local_host = "127.0.0.1";
 static int do_mail_notify = 1;
 static int do_yahoo_debug = 0;
 static int ignore_system = 0;
@@ -150,89 +150,25 @@ rearm (time_t * timer, int seconds)
   *timer += seconds;
 }
 
-#if 0
-/* This code is buggy and non-portable. Output of "netstat" and
-"ifconfig" has changed resulting in memory corruption. */
 static char *
-get_local_addresses ()
+get_local_address ()
 {
-  static char addresses[1024];
+  static char ip_address[1024];
   char buff[1024];
-  char interface[16];
-  char popen_cmd[32];
-  char *c = NULL;
   struct hostent *hn;
-  FILE *f;
 
-  f = popen ("netstat -nr", "r");
-  if (f == NULL)
-    goto IP_TEST_2;
-  while (fgets (buff, sizeof (buff), f) != NULL)
-    {
-      c = strtok (buff, " "); /* dest */
-      if ((strstr (c, "default") || strstr (c, "0.0.0.0")) &&
-	  !strstr (c, "127.0.0"))
-	{
-	  c = strtok (NULL, " "); /* gateway */
-	  c = strtok (NULL, " "); /* mask */
-	  c = strtok (NULL, " "); /* flags */
-	  c = strtok (NULL, " "); /* mss */
-	  c = strtok (NULL, " "); /* window */
-	  c = strtok (NULL, " "); /* irtt */
-	  c = strtok (NULL, " "); /* iface */
-	  pclose (f);
-	  break;
-	}
-      else
-	c = NULL;
-    }
-
-  if (!c || !c[0])
-    goto IP_TEST_2;
-  
-  strncpy (interface, c, 16);
-  interface[16] = '\0'; /* just in case */
-  if(interface[strlen(interface)-1] == '\n')
-    interface[strlen(interface)-1] = '\0';
-
-  sprintf(popen_cmd,"/sbin/ifconfig %s",interface);
-  f = popen (popen_cmd, "r");
-  if (f == NULL)
-    goto IP_TEST_2;
-
-  while (fgets (buff, sizeof (buff), f) != NULL)
-    {
-      if (strstr (buff, "inet"))
-	break;
-    }
-  pclose (f);
-
-  c = strtok (buff, " ");
-  c = strtok (NULL, " ");
-
-  strncpy (addresses, c, sizeof (addresses));
-  c = strtok (addresses, ":");
-  strncpy (buff, c, sizeof (buff));
-  if ((c = strtok (NULL, ":")))
-    strncpy (buff, c, sizeof (buff));
-
-  strncpy (addresses, buff, sizeof (addresses));
-
-  return addresses;
-
-IP_TEST_2:
   gethostname (buff, sizeof (buff));
 
   hn = gethostbyname (buff);
   if (hn)
-    strncpy (addresses, inet_ntoa (*((struct in_addr *) hn->h_addr)),
-	     sizeof (addresses));
+    strncpy (ip_address, inet_ntoa (*((struct in_addr *) hn->h_addr)),
+	     sizeof (ip_address));
   else
-    addresses[0] = 0;
+    ip_address[0] = 0;
 
-  return addresses;
+  return ip_address;
 }
-#endif
+
 
 static double
 get_time ()
@@ -682,7 +618,10 @@ ext_yahoo_contact_added (int id, const char *myid, const char *who, const char *
 {
   char buf[1024];
 
-  PRINTF_MESSAGE ("%s has added you to their contact list.\n", who);
+  PRINTF_MESSAGE ("%s has added you to their contact list%s%s\n", who,
+		  (msg ? " with the message:\n" : "."),
+		  (msg ? msg : ""));
+
   PRINTF_MESSAGE ("Use \"/add %s\" to add %s to your contact list\n", who, who);
   PRINTF_MESSAGE ("or Use \"/reject %s [MSG]\" to reject %s.\n", who, who);
 
@@ -939,8 +878,8 @@ ext_yahoo_login (yahoo_local_account * ylad, int login_mode)
   LOG (("ext_yahoo_login"));
 
   ylad->id = yahoo_init_with_attributes (ylad->yahoo_id, ylad->password,
-					 "local_host", "127.0.0.1",
-					 "pager_port", 23, NULL);
+					 "local_host", local_host,
+					 "pager_port", 5050, NULL);
   ylad->status = YAHOO_STATUS_OFFLINE;
   yahoo_login (ylad->id, login_mode);
 
@@ -977,7 +916,7 @@ ext_yahoo_login_response (int id, int succ, const char *url)
             {
               yahoo_add_buddy (get_fh_session ()->id,
                                FH_ROBOT,
-                               FH_ROBOT_GROUP, "");
+                               FH_ROBOT_GROUP, "Hi this is Gnubot");
             }
         }
       return;
@@ -1644,8 +1583,7 @@ messenger_main (int argc, char *argv[])
 
   ylad = y_new0 (yahoo_local_account, 1);
 
-  // FIXME: get_local_address () is BUGGY.
-  //  local_host = strdup (get_local_addresses ());
+  local_host = strdup (get_local_address ());
 
   if (!login_id)
     {
