@@ -20,8 +20,8 @@
 #ifndef _YAHOO_BACKEND_H
 #define _YAHOO_BACKEND_H
 
-#include <yahoo2.h>
-#include <yahoo2_callbacks.h>
+#include <libyahoo2/yahoo2.h>
+#include <libyahoo2/yahoo2_callbacks.h>
 
 #define MAX_PREF_LEN 255
 #define YAHOO_DEBUGLOG ext_yahoo_log
@@ -104,8 +104,6 @@ typedef struct get_file_geturl_data get_file_geturl_data_t;
 
 void get_file_geturl_callback(int id, int fd, int error, const char * filename, unsigned long size, void *data);
 
-void ext_yahoo_got_im (int id, char *who, char *msg, long tm,
-		       int stat, int utf8);
 void register_callbacks ();
 conf_room *find_conf_room_by_name_and_id (int id, const char * name);
 void main_loop ();
